# Detect the distribution in use
%global __despace head -n 1 | tr -d '[:space:]' | sed -e 's/[(].*[)]//g'
%global __lower4 cut -c 1-4 | tr '[:upper:]' '[:lower:]'
%global __distfile %([ -f /etc/SuSE-release ] && echo /etc/SuSE-release || echo /etc/redhat-release)
%global __distinit %(sed -e 's/ release .*//' -e 's/\\([A-Za-z]\\)[^ ]*/\\1/g' %{__distfile} | %{__despace} | %{__lower4})
%global __distvers %(sed -e 's/.* release \\([^. ]*\\).*/\\1/' %{__distfile} | %{__despace})
# Identify Alma, CentOS, CentOS Stream and Rocky Linux as rhel
%if "%{__distinit}" == "a" || "%{__distinit}" == "c" || "%{__distinit}" == "cl" || "%{__distinit}" == "cs" || "%{__distinit}" == "rl"
%global __distinit rhel
%endif
# Dist tag for Fedora is still "fc"
%if "%{__distinit}" == "f"
%global __distinit fc
%endif

# libyaml ≥ 0.2.4 available from Fedora 33 onwards
%if 0%{?fedora} >= 33
%global unbundle_libyaml 1
%endif

Name:		perl-YAML-LibYAML
Epoch:		1
Version:	0.89
Release:	1.%{__distinit}%{__distvers}
Summary:	Perl YAML Serialization using XS and libyaml
%if 0%{?unbundle_libyaml}
License:	GPL-1.0-or-later OR Artistic-1.0-Perl
%else
# Bundled libyaml is MIT-licensed
License:	MIT AND (GPL-1.0-or-later OR Artistic-1.0-Perl)
%endif
URL:		https://metacpan.org/release/YAML-LibYAML
Source0:	https://cpan.metacpan.org/modules/by-module/YAML/YAML-LibYAML-%{version}.tar.gz
Patch0:		YAML-LibYAML-0.79-Unbundled-libyaml.patch
# Module Build
BuildRequires:	coreutils
BuildRequires:	findutils
BuildRequires:	gcc
%if 0%{?unbundle_libyaml}
BuildRequires:	libyaml-devel >= 0.2.4, sed
%endif
BuildRequires:	make
BuildRequires:	perl-devel
BuildRequires:	perl-generators
BuildRequires:	perl-interpreter
BuildRequires:	perl(Config)
BuildRequires:	perl(ExtUtils::MakeMaker)
# Module Runtime
BuildRequires:	perl(B::Deparse)
BuildRequires:	perl(base)
BuildRequires:	perl(constant)
BuildRequires:	perl(Exporter)
BuildRequires:	perl(Scalar::Util)
BuildRequires:	perl(strict)
BuildRequires:	perl(warnings)
BuildRequires:	perl(XSLoader)
# Test Suite
BuildRequires:	perl(B)
BuildRequires:	perl(blib)
BuildRequires:	perl(Carp)
BuildRequires:	perl(Data::Dumper)
BuildRequires:	perl(Devel::Peek)
BuildRequires:	perl(Encode)
BuildRequires:	perl(File::Find)
BuildRequires:	perl(File::Path)
BuildRequires:	perl(Filter::Util::Call)
BuildRequires:	perl(FindBin)
BuildRequires:	perl(if)
BuildRequires:	perl(IO::File)
BuildRequires:	perl(IO::Pipe)
BuildRequires:	perl(lib)
BuildRequires:	perl(Test::Builder)
BuildRequires:	perl(Test::More) >= 0.90
BuildRequires:	perl(Tie::Array)
BuildRequires:	perl(Tie::Hash)
BuildRequires:	perl(utf8)
# Optional Tests
BuildRequires:	perl(boolean)
%if 0%{!?perl_bootstrap:1}
BuildRequires:	perl(Path::Class)
%endif
# Dependencies
%if 0%{?fedora} < 38 && 0%{?rhel} < 10
Requires:	perl(:MODULE_COMPAT_%(eval "`perl -V:version`"; echo $version))
%endif
Requires:	perl(B::Deparse)

%if 0%{?unbundle_libyaml}
Requires:	libyaml >= 0.2.4
%else
# Bundled libyaml version number determined by comparing commits in upstream repo:
# https://github.com/yaml/libyaml/
Provides:	bundled(libyaml) = 0.2.4
%endif

# Avoid provides for private objects
%{?perl_default_filter}

%description
Kirill Siminov's "libyaml" is arguably the best YAML implementation. The C
library is written precisely to the YAML 1.1 specification. It was originally
bound to Python and was later bound to Ruby.

%prep
%setup -q -n YAML-LibYAML-%{version}

# Unbundle libyaml if we have a recent enough system version
%if 0%{?unbundle_libyaml}
%patch -P 0 -p1
for file in api.c dumper.c emitter.c loader.c parser.c reader.c scanner.c \
	writer.c yaml.h yaml_private.h; do
	rm LibYAML/$file
	sed -i -e "/^LibYAML\/$file/d" MANIFEST
done
%endif

%build
perl Makefile.PL INSTALLDIRS=vendor OPTIMIZE="%{optflags}"
make %{?_smp_mflags}

%install
make pure_install DESTDIR=%{buildroot}
find %{buildroot} -type f -name .packlist -delete
find %{buildroot} -type f -name '*.bs' -empty -delete
%{_fixperms} -c %{buildroot}

%check
make test

%files
%if 0%{?unbundle_libyaml}
%license LICENSE
%else
%license LICENSE LibYAML/License
%endif
%doc Changes CONTRIBUTING README
%{perl_vendorarch}/auto/YAML/
%{perl_vendorarch}/YAML/
%{_mandir}/man3/YAML::LibYAML.3*
%{_mandir}/man3/YAML::XS.3*
%{_mandir}/man3/YAML::XS::LibYAML.3*

%changelog
* Sat Jan 27 2024 Paul Howarth <paul@city-fan.org> - 1:0.89-1
- Update to 0.89 (rhbz#2260595)
  - Recognise core booleans on Perl 5.36+ at dump time (GH#114)

* Tue Jul 11 2023 Paul Howarth <paul@city-fan.org> - 1:0.88-2
- Perl 5.38 rebuild

* Fri May 12 2023 Paul Howarth <paul@city-fan.org> - 1:0.88-1
- Update to 0.88
  - REVERT "Turn off internal POK flag for number scalars"

* Fri May  5 2023 Paul Howarth <paul@city-fan.org> - 1:0.87-1
- Update to 0.87
  - Turn off internal POK flag for number scalars
- Avoid use of deprecated patch syntax
- Note that bundled libyaml (if used) is MIT-licensed

* Thu Jan 26 2023 Paul Howarth <paul@city-fan.org> - 1:0.86-1
- Update to 0.86
  - Fix YAML::XS pod in cpanminus

* Mon Sep 12 2022 Paul Howarth <paul@city-fan.org> - 1:0.85-1
- Update to 0.85
  - Convert doc from Swim to Markdown
  - Remove travis testing

* Sun Sep  4 2022 Paul Howarth <paul@city-fan.org> - 1:0.84-1
- Update to 0.84
  - Add option ForbidDuplicateKeys (GH#105)
- Use SPDX-format license tag

* Tue May 31 2022 Paul Howarth <paul@city-fan.org> - 1:0.83-5
- Perl 5.36 rebuild

* Fri May 21 2021 Paul Howarth <paul@city-fan.org> - 1:0.83-2
- Perl 5.34 rebuild

* Sun May  9 2021 Paul Howarth <paul@city-fan.org> - 1:0.83-1
- Update to 0.83
  - Recognize tied variables (GH#101)
  - Add license file from included libyaml code (GH#102)

* Wed Jun 24 2020 Paul Howarth <paul@city-fan.org> - 1:0.82-2
- Perl 5.32 rebuild

* Sun May  3 2020 Paul Howarth <paul@city-fan.org> - 1:0.82-1
- Update to 0.82
  - Updated libyaml sources to 0.2.4; changes affecting YAML::XS are:
    - Output '...' at the stream end after a block scalar with trailing empty
      lines
    - Accept '%%YAML 1.2' directives (they are ignored and do not change
      behaviour though)

* Tue Jan 28 2020 Paul Howarth <paul@city-fan.org> - 1:0.81-1
- Update to 0.81
  - Breaking Change: Set $YAML::XS::LoadBlessed default to false to make it
    more secure

* Thu Aug 22 2019 Paul Howarth <paul@city-fan.org> - 1:0.80-1
- Update to 0.80
  - Fix memory leak when loading invalid YAML (GH#93)

* Wed Jun 12 2019 Paul Howarth <paul@city-fan.org> - 1:0.79-1
- Update to 0.79
  - Support aliasing scalars resolved as null or booleans
  - Add YAML::XS::LibYAML::libyaml_version()
  - Support standard !!int/!!float tags instead of dying
- Unbundle libyaml where possible

* Thu May 30 2019 Paul Howarth <paul@city-fan.org> - 1:0.78-2
- Perl 5.30 rebuild

* Sun May 19 2019 Paul Howarth <paul@city-fan.org> - 1:0.78-1
- Update to 0.78
  - Fix double free/core dump when Dump()ing binary data (GH#91)
  - Update config.h from libyaml

* Tue Apr 16 2019 Paul Howarth <paul@city-fan.org> - 1:0.77-1
- Update to 0.77
  - Update libyaml to version 0.2.2; most important change for users is that
    plain urls in flow style can now be parsed

* Wed Jan  2 2019 Paul Howarth <paul@city-fan.org> - 1:0.76-1
- Update to 0.76
  - Add $Indent - number of spaces when dumping (GH#89)
  - Fix typo in docs (GH#87)
  - Fix links in docs

* Sat Nov  3 2018 Paul Howarth <paul@city-fan.org> - 1:0.75-1
- Update to 0.75
  - Implement $LoadCode

* Mon Sep  3 2018 Paul Howarth <paul@city-fan.org> - 1:0.74-1
- Update to 0.74
  - Fix tests on older perls
  - Support back to perl 5.8.1

* Mon Jul  9 2018 Paul Howarth <paul@city-fan.org> - 1:0.72-1
- Update to 0.72
  - Update to libyaml 0.2.1: it's forbidden now to escape single quotes inside
    double quotes
  - When disabling $LoadBlessed, return scalars rather than refs
  - Save anchors also for blessed scalars

* Wed Jun 27 2018 Paul Howarth <paul@city-fan.org> - 1:0.70-2
- Perl 5.28 rebuild

* Sun Jun 10 2018 Paul Howarth <paul@city-fan.org> - 1:0.70-1
- Update to 0.70
  - Fix format specifier/argument mismatch (GH#79)
  - Travis CI: Test on Perl 5.26 (GH#80)
  - Fix a C90-compatibility issue (GH#81)
- Switch upstream from search.cpan.org to metacpan.org

* Thu Dec 28 2017 Paul Howarth <paul@city-fan.org> - 1:0.69-1
- Update to 0.69
  - Security fix: Add $LoadBlessed option to turn on/off loading objects
    (GH#73, GH#74)

* Tue Dec 19 2017 Paul Howarth <paul@city-fan.org> - 1:0.68-1
- Update to 0.68
  - Fix regex roundtrip (GH#69, GH#70)
  - Fix loading of many regexes (GH#64, GH#71)

* Thu Nov 16 2017 Paul Howarth <paul@city-fan.org> - 1:0.67-1
- Update to 0.67
  - Support standard tags !!str, !!map and !!seq instead of dying (GH#67)
  - Support JSON::PP::Boolean and boolean.pm via $YAML::XS::Boolean (GH#66)

* Fri Aug 18 2017 Paul Howarth <paul@city-fan.org> - 1:0.66-1
- Update to 0.66
  - Dump() was modifying original data, adding a PV to numbers (GH#32, GH#55)

* Fri Aug  4 2017 Paul Howarth <paul@city-fan.org> - 1:0.65-4
- BR: perl-generators unconditionally
- BR: perl-interpreter rather than perl

* Sun Jun 11 2017 Paul Howarth <paul@city-fan.org> - 1:0.65-2
- Perl 5.26 rebuild

* Fri May 19 2017 Paul Howarth <paul@city-fan.org> - 1:0.65-1
- Update to 0.65
  - Prevent warning about unused variables (GH#59)
  - Clarify documentation about exported functions

* Sun Apr  9 2017 Paul Howarth <paul@city-fan.org> - 1:0.64-1
- Update to 0.64
  - use lib FindBin::Bin in tests, preparing for perl 5.26 where '.' gets
    removed from @INC (GH#54)
  - Use the latest libyaml sources
  - Lazy load B::Deparse for faster startup time (GH#52, GH#53)
- Drop support for EOL distributions prior to F-13
  - Drop BuildRoot: and Group: tags
  - Drop explicit buildroot cleaning in %%install section
  - Drop explicit %%clean section
  - Drop support for building with Test::More < 0.88
- Add provide for bundled(libyaml)

* Tue Mar  7 2017 Paul Howarth <paul@city-fan.org> - 1:0.63-2
- Revert to 0.63; the 0.71 release was unauthorized

* Wed Oct 26 2016 Paul Howarth <paul@city-fan.org> - 0.71-2
- Don't BR: perl(Path::Class) when bootstrapping

* Thu Sep  8 2016 Paul Howarth <paul@city-fan.org> - 0.71-1
- Update to 0.71
  - Merge with libyaml 0.1.7 upstream
  - cperl fixes for fake_signatures
  - libyaml fix C++-compat errors
  - Improve Makefile for Win32
  - Improve ppport_sort.h
  - Implement new NonStrict mode (for perl5 compat)
  - libyaml reformat, minor optimizations, fix warnings
  - Update documentation
  - Use error codes, return undef on error
  - Abstract the loader functionality to load_impl(), dump_impl() not yet
  - Rearrange static funcs (not decl in header)
  - DumpFile,LoadFile is now XS only, and do accept mg pv, io objects and
    fileglobs; support filename in error messages
  - Support $YAML::XS::NonStrict loader
  - Add dumper options Indent, BestWidth, Canonical, Unicode, Encoding,
    LineBreak, OpenEnded (kept defaults)
  - Add loader option NonStrict, Encoding (kept defaults)
  - Fix default emitter_set_width (2 ⇒ 80)
  - Fix the tests for the new default IndentlessMap=0 and check also
    IndentlessMap=1
  - Enable 2 more test/glob.t tests
  - Fix dump_yaml in test/TestYAMLTests.pm
  - Avoid duplicate checks against NULL
- This release by RURBAN → update source URL

* Fri Jul  8 2016 Paul Howarth <paul@city-fan.org> - 0.63-1
- Update to 0.63
  - Fix memory leaks (GH#48)
- BR: perl-generators where available
- Simplify find commands using -empty and -delete

* Mon Feb 22 2016 Paul Howarth <paul@city-fan.org> - 0.62-1
- Update to 0.62
  - Fix for detecting filehandles (GH#42)
- This release by TINITA → update source URL

* Sun Feb 21 2016 Paul Howarth <paul@city-fan.org> - 0.61-1
- Update to 0.61
  - Allow reading from and writing to IO::Handle (and derived) objects (GH#37)

* Wed Feb 10 2016 Paul Howarth <paul@city-fan.org> - 0.60-1
- Update to 0.60
  - Compilation fix for Solaris (GH#24)
- Explicitly BR: perl-devel, needed for EXTERN.h

* Tue Jan 27 2015 Paul Howarth <paul@city-fan.org> - 0.59-1
- Update to 0.59
  - Better scalar dump heuristics (PR/23)
  - More closely match YAML.pm

* Wed Jan 21 2015 Paul Howarth <paul@city-fan.org> - 0.58-1
- Update to 0.58
  - Add a VERSION statement to YAML::LibYAML (GH#8)
- This release by INGY → update source URL

* Fri Jan 16 2015 Paul Howarth <paul@city-fan.org> - 0.57-1
- Update to 0.57
  - Update copyright year
  - Use Swim cpan-tail block functions in doc
  - Format string fixes (PR#21, CPAN RT#46507, CVE-2012-1152)
- This release by NAWGLAN → update source URL
- Drop patch for format string fixes, upstreamed at long last

* Wed Dec 24 2014 Paul Howarth <paul@city-fan.org> - 0.55-1
- Update to 0.55
  - Get YAML::XS using latest libyaml

* Sun Nov 30 2014 Paul Howarth <paul@city-fan.org> - 0.54-1
- Update to 0.54
  - Fix for an edge case in scanner that results in an assert() failing
    (https://bitbucket.org/xi/libyaml/issue/10/wrapped-strings-cause-assert-failure)
    (CVE-2014-9130)
- Drop upstreamed patches for CVE-2013-6393 and CVE-2014-2525

* Tue Nov 18 2014 Paul Howarth <paul@city-fan.org> - 0.52-3
- Fix FTBFS due to missing Filter::Util::Call (#1165198)

* Fri Aug 29 2014 Paul Howarth <paul@city-fan.org> - 0.52-2
- Perl 5.20 rebuild

* Sun Aug 24 2014 Paul Howarth <paul@city-fan.org> - 0.52-1
- Update to 0.52
  - Fix e1 test failure on 5.21.4

* Mon Aug 18 2014 Paul Howarth <paul@city-fan.org> - 0.51-1
- Update to 0.51 (various minor tidy-ups, no functional changes)
- Add patch to support building with Test::More < 0.88

* Sat Aug  9 2014 Paul Howarth <paul@city-fan.org> - 0.47-1
- Update to 0.47:
  - Fix swim errors

* Wed Aug  6 2014 Paul Howarth <paul@city-fan.org> - 0.46-1
- Update to 0.46:
  - Add badges to docs
  - Fix README

* Tue Aug  5 2014 Paul Howarth <paul@city-fan.org> - 0.45-1
- Update to 0.45:
  - Fix Meta and add Contributing
- Include LICENSE file

* Mon Jul 14 2014 Paul Howarth <paul@city-fan.org> - 0.44-1
- Update to 0.44:
  - Switch to Zilla::Dist
  - No longer dep on Test::Base, Spiffy, and Filter::Util::Call
  - Remove test/changes.t

* Thu Mar 27 2014 Paul Howarth <paul@city-fan.org> - 0.41-4
- Fix LibYAML input sanitization errors (CVE-2014-2525)
- Fix heap-based buffer overflow when parsing YAML tags (CVE-2013-6393)
- Drop %%defattr, redundant since rpm 4.4
- Classify buildreqs by usage

* Wed Mar 13 2013 Paul Howarth <paul@city-fan.org> - 0.41-1
- Update to 0.41:
  - Removed C++ // style comments, for better portability

* Tue Feb 12 2013 Paul Howarth <paul@city-fan.org> - 0.39-1
- Update to 0.39:
  - Using the latest libyaml codebase
    (https://github.com/yaml/libyaml/tree/perl-yaml-xs)
  - Changes have been made to start moving libyaml to 1.2

* Tue Jun 12 2012 Paul Howarth <paul@city-fan.org> - 0.38-3
- BR: perl(Data::Dumper)

* Thu Mar 29 2012 Paul Howarth <paul@city-fan.org> - 0.38-2
- Fix various format string vulnerabilities (CVE-2012-1152, CPAN RT#46507)
- BR: Perl core modules that might be dual-lived
- Don't need to remove empty directories from buildroot
- Drop support for distributions prior to FC-3:
  - Use %%{_fixperms} macro rather than our own chmod incantation
  - Use DESTDIR rather than PERL_INSTALL_ROOT

* Wed Jan  4 2012 Paul Howarth <paul@city-fan.org> - 0.38-1
- Update to 0.38
  - Apply SPROUT++ deparse test patch

* Thu Sep 29 2011 Paul Howarth <paul@city-fan.org> - 0.37-1
- Update to 0.37
  - Switch to Module::Package
  - Fix LoadFile on empty file failure

* Sat Aug  6 2011 Paul Howarth <paul@city-fan.org> - 0.35-3
- Fix dist tag for CentOS 6 and Scientific Linux

* Thu Jun 30 2011 Paul Howarth <paul@city-fan.org> - 0.35-2
- Rebuild for perl 5.14.1 in Rawhide

* Sun Apr  3 2011 Paul Howarth <paul@city-fan.org> - 0.35-1
- Update to 0.35
  - Fix memory leaks in YAML::XS::Load() (CPAN RT#46172)
  - Fix builds on older Perls (CPAN RT#64749 and CPAN RT#62054)
  - Fix regexp.t for bleadperl (CPAN RT#62266)
- Drop ppport.h patch, no longer needed
- Nobody else likes macros for commands

* Wed Mar 16 2011 Paul Howarth <paul@city-fan.org> - 0.34-4
- Import from Fedora

* Wed Feb 09 2011 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.34-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_15_Mass_Rebuild

* Wed Sep 29 2010 jkeating - 0.34-2
- Rebuilt for gcc bug 634757

* Fri Sep 24 2010 Marcela Mašláňová <mmaslano@redhat.com> - 0.34-1
- Update

* Thu Jun  3 2010 Marcela Maslanova <mmaslano@redhat.com> - 0.33-1
- Update

* Fri May 07 2010 Marcela Maslanova <mmaslano@redhat.com> - 0.32-6
- Mass rebuild with perl-5.12.0

* Sat Mar 27 2010 Chris Weyl <cweyl@alumni.drew.edu> - 0.32-5
- perl_default_filter, PERL_INSTALL_ROOT => DESTDIR

* Mon Dec  7 2009 Stepan Kasal <skasal@redhat.com> - 0.32-4
- Rebuild against perl 5.10.1

* Sun Jul 26 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.32-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_12_Mass_Rebuild

* Wed Apr 29 2009 Marcela Mašláňová <mmaslano@redhat.com> 0.32-2
- Add BR

* Wed Apr 29 2009 Marcela Mašláňová <mmaslano@redhat.com> 0.32-1
- Specfile autogenerated by cpanspec 1.78
